==> eiffelstudio-23.09.10.7341.tar: F_code/C1/ut2.c <==
/*
 * Code for class UTF8_READER_WRITER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ut2.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {UTF8_READER_WRITER}.file_read_string_32_with_length */
EIF_REFERENCE F2_35 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,Result);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("file_read_string_32_with_length", 1, Current, 1, 2, 32);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(arg2 == ((EIF_INTEGER_32) 0L))) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(1118, 0x01).id, 1118, _OBJSIZ_1_1_0_3_0_0_0_0_);
		F1114_10117(RTCW(tr1));
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(4);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R7252[Dtype(RTCW(arg1))-1030])(arg1, arg2);
		RTHOOK(5);
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			RTHOOK(7);
			tr1 = RTLNS(eif_new_type(82, 0x00).id, 82, _OBJSIZ_0_0_0_0_0_0_0_0_);
			Result = F83_1212(RTCW(tr1), loc1);
		} else {
			RTHOOK(8);
			Result = RTLNS(eif_new_type(1118, 0x01).id, 1118, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F1114_10117(RTCW(Result));
			RTHOOK(9);
			RTLE;
			RTEE;
			return (EIF_REFERENCE) Result;
		}
	}
	RTHOOK(11);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit2 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C1/ut2.c <==
/*
 * Code for class UTF8_READER_WRITER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ut2.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {UTF8_READER_WRITER}.file_read_string_32_with_length */
EIF_REFERENCE F2_35 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,Result);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("file_read_string_32_with_length", 1, Current, 1, 2, 32);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(arg2 == ((EIF_INTEGER_32) 0L))) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(1532, 0x00).id, 1532, _OBJSIZ_1_1_0_3_0_0_0_0_);
		F1523_14700(RTCW(tr1));
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(4);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R9234[Dtype(RTCW(arg1))-1233])(arg1, arg2);
		RTHOOK(5);
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + O9162[Dtype(arg1)-1230]);
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			RTHOOK(7);
			tr1 = RTLNS(eif_new_type(106, 0x00).id, 106, _OBJSIZ_0_0_0_0_0_0_0_0_);
			Result = F107_1876(RTCW(tr1), loc1);
		} else {
			RTHOOK(8);
			Result = RTLNS(eif_new_type(1532, 0x00).id, 1532, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F1523_14700(RTCW(Result));
			RTHOOK(9);
			RTLE;
			RTEE;
			return (EIF_REFERENCE) Result;
		}
	}
	RTHOOK(11);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit2 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
